/************************************************************************
 *   MODULE  : RSTRASGN.C
 *
 *   PURPOSE : provides routines to intialize certain data_hdr and
 *             data_matrix structure variables.  Both routines are
 *             called by do_prod in module DO_PROD.C
 *
 *   AUTHOR  : Ron Hawkins & Craig Woodfolk, SAIC (original)
 *             Kevin Russo, SAIC (1, 2)
 *
 *   Change     Date          Reason
 *   ------     ----          ------
 *   Original   25 Sep 92     n/a
 *   1          20 Oct 92     overall program update
 *   2          21 Jun 93     update to XVT 3.0 and MUSE Beta Release 3
 *
 ************************************************************************/

/****************
 * header files *
 ****************/

#include "los.h"

/************************************************************************
 *   FUNCTION     : raster_assign
 *
 *   PURPOSE      : sets the defaults for the product raster
 *
 *   INPUTS       : prod_raster - pointer to the product raster
 *
 *   RETURN VALUE : void
 *
 *   CALLED FROM  : do_prod in module DO_PROD.C
 *
 *   CALLS        : palette_construct {MUSE LIB}
 *
 ************************************************************************/

#ifdef PROTO
void raster_assign( RASTER **tprod_raster )
#else
void raster_assign( tprod_raster )
RASTER **tprod_raster;
#endif
{
   PALETTE *palette;               /* default raster palette           */

   extern RASTER elev_raster;      /* DTED elevation raster            */

   /********************************************************************
    * Please note that some specific parameters will be calculated in  *
    * the function init_ui().                                          *
    ********************************************************************/

   /* assignment of data elements */
   (*tprod_raster)->magic       = elev_raster.magic;
   (*tprod_raster)->data_hdr    = elev_raster.data_hdr;
   (*tprod_raster)->data_matrix = elev_raster.data_matrix;

   /* assignment of data matrix elements */
   (*tprod_raster)->data_matrix.bits_per_pixel = 8 * sizeof(char);
   (*tprod_raster)->data_matrix.num_type       = UINT_8BIT;
   (*tprod_raster)->data_matrix.data_type      = COLOR_INDIRECT;
   (*tprod_raster)->data_matrix.ghandle        = (GHANDLE)NULL;

   /* no lookup table for this raster */
   (*tprod_raster)->lut                        = (LUT *)NULL;

   /* get a default palette */
   palette_construct (NULL, &palette);
   (*tprod_raster)->palette = palette;
}
