/*
 * Copyright 1994, 1995 Vectaport Inc.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation for any purpose is hereby granted without fee, provided
 * that the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the names of the copyright holders not be used in
 * advertising or publicity pertaining to distribution of the software
 * without specific, written prior permission.  The copyright holders make
 * no representations about the suitability of this software for any purpose.
 * It is provided "as is" without express or implied warranty.
 *
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 * 
 */

#include <MapUnidraw/mapstates.h>
#include <InterViews/layout.h>
#include <InterViews/patch.h>
#include <IV-look/kit.h>
#include <stdio.h>

/*****************************************************************************/

ProjectionState::ProjectionState(const char* pr, const char** parm)
:NameState(pr)
{
    _projection = (char*)pr;
    _parms = parm;
    name(_projection, false);
}

ProjectionState::~ProjectionState() {}

const char* ProjectionState::projection() { return _projection; }
const char** ProjectionState::params() { return _parms; }

void ProjectionState::projection(const char* pr, const char** parm,
				 boolean notif)
{
    _projection = (char*)pr;
    _parms = parm;
    name(pr, notif);
}

/*****************************************************************************/

MapFClassState::MapFClassState(const char* fc, const char* fcdesc)
:NameState(nil)
{
    _mapfclass = (char*)fc;
    _mapfclassdesc = (char*)fcdesc;
    sprintf(buf, "Feature Class: %s", _mapfclassdesc);
    name(buf, false);
}

MapFClassState::~MapFClassState() {}

const char* MapFClassState::mapfclass() { return _mapfclass; }
const char* MapFClassState::mapfclassdesc() { return _mapfclassdesc; }

void MapFClassState::mapfclass(const char* fc, const char* fcdesc,
			       boolean notif)
{
    _mapfclass = (char*)fc;
    _mapfclassdesc = (char*)fcdesc;
    sprintf(buf, "Feature Class: %s", _mapfclassdesc);
    name(buf, notif);
}

/*****************************************************************************/

MapCovState::MapCovState(MapFClassState* fcs, const char* cov, const char* covdesc)
:NameState(nil)
{
    _fcstate = fcs;
    _mapcov = (char*)cov;
    _mapcovdesc = (char*)covdesc;
    sprintf(buf, "Coverage: %s", _mapcovdesc);
    name(buf, false);
}

MapCovState::~MapCovState() {}

const char* MapCovState::mapcov() { return _mapcov; }
const char* MapCovState::mapcovdesc() { return _mapcovdesc; }

void MapCovState::mapcov(const char* cov, const char* covdesc,
			       boolean notif)
{
    _mapcov = (char*)cov;
    _mapcovdesc = (char*)covdesc;
    sprintf(buf, "Coverage: %s", _mapcovdesc);
    name(buf, notif);
    _fcstate->mapfclass("", "", notif);
}

/*****************************************************************************/

MapLibState::MapLibState(MapCovState* cs, const char* lib)
:NameState(nil)
{
    _covstate = cs;
    _maplib = (char*)lib;
    sprintf(buf, "Library: %s", _maplib);
    name(buf, false);
}

MapLibState::~MapLibState() {}

const char* MapLibState::maplib() { return _maplib; }

void MapLibState::maplib(const char* lib, boolean notif)
{
    _maplib = (char*)lib;
    sprintf(buf, "Library: %s", _maplib);
    name(buf, notif);
    _covstate->mapcov("", "", notif);
}

/*****************************************************************************/

MapDbState::MapDbState(MapLibState* ls, const char* db)
:NameState(nil)
{
    _libstate = ls;
    _mapdb = (char*)db;
    sprintf(buf, "Database: %s", _mapdb);
    name(buf, false);
}

MapDbState::~MapDbState() {}

const char* MapDbState::mapdb() { return _mapdb; }

void MapDbState::mapdb(const char* db, boolean notif)
{
    _mapdb = (char*)db;
    sprintf(buf, "Database: %s", _mapdb);
    name(buf, notif);
    _libstate->maplib("", notif);
}

/*****************************************************************************/

MapSelectionState::MapSelectionState(const char* sel)
:NameState(nil)
{
    _mapselection = (char*)sel;
    sprintf(buf, "Inspection: %s", _mapselection);
    name(buf, false);
}

MapSelectionState::~MapSelectionState() {}

const char* MapSelectionState::mapselection() { return _mapselection; }

void MapSelectionState::mapselection(const char* sel, boolean notif)
{
    _mapselection = (char*)sel;
    sprintf(buf, "Inspection: %s", _mapselection);
    name(buf, notif);
}

